package com.eleadmin.common.goods.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.eleadmin.common.core.annotation.OperationLog;
import com.eleadmin.common.core.web.ApiResult;
import com.eleadmin.common.core.web.BaseController;
import com.eleadmin.common.core.web.PageParam;
import com.eleadmin.common.core.web.PageResult;
import com.eleadmin.common.goods.entity.Goods;
import com.eleadmin.common.goods.param.GoodsParam;
import com.eleadmin.common.goods.service.GoodsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.util.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.UUID;

/**
 * 商品控制器
 *
 * @program: ele-admin-api
 * @ClassName: GoodsController
 * @author: Gyc
 * @create: 2024-04-21 09:44
 **/
@Api("商品管理")
@RestController
@RequestMapping("/api/goods")
public class GoodsController extends BaseController {
    @Resource
    private GoodsService goodsService;

    @PreAuthorize("hasAnyAuthority('goods:list')")
    @OperationLog
    @ApiOperation("分页查询商品")
    @GetMapping("/page")
    public ApiResult<PageResult<Goods>> page(GoodsParam param) {
        Page<Goods> goodsPage = new Page<>(param.getPage(), param.getLimit());
        LambdaQueryWrapper<Goods> goodsLambdaQueryWrapper = new LambdaQueryWrapper<>();

        goodsLambdaQueryWrapper.like(!StringUtils.isEmpty(param.getGoodId()),Goods::getGoodId,param.getGoodId());

        goodsLambdaQueryWrapper.like(!StringUtils.isEmpty(param.getTitle()),Goods::getTitle,param.getTitle());

        return success(goodsService.page(goodsPage,goodsLambdaQueryWrapper));
    }

    @PreAuthorize("hasAnyAuthority('goods:save')")
    @OperationLog
    @ApiOperation("添加商品")
    @PostMapping
    public ApiResult<?> save(@Valid @RequestBody Goods goods, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            throw new RuntimeException(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        goods.setGoodId(UUID.randomUUID().toString().toString());
        boolean save = goodsService.save(goods);
        return save?success():fail();
    }
    @PreAuthorize("hasAnyAuthority('goods:update')")
    @OperationLog
    @ApiOperation("修改商品")
    @PutMapping
    public ApiResult<?> update(@Valid @RequestBody Goods goods, BindingResult bindingResult) {
        if (goods.getId()==null){
            throw new RuntimeException("id不能为空");
        }
        if (bindingResult.hasErrors()) {
            throw new RuntimeException(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        boolean b = goodsService.updateById(goods);
        return b?success():fail();

    }

    @PreAuthorize("hasAnyAuthority('goods:remove')")
    @OperationLog
    @ApiOperation("删除商品")
    @DeleteMapping("/del")
    public ApiResult<?> remove(@RequestParam Integer id) {
        boolean b = goodsService.removeById(id);
        return b?success():fail();
    }


    @PreAuthorize("hasAnyAuthority('goods:remove')")
    @OperationLog
    @ApiOperation("批量删除商品")
    @DeleteMapping("/delAll")
    public ApiResult<?> removeAll(@RequestParam String arr) {
        String[] split = arr.split(",");
        ArrayList<String> list = new ArrayList<>(Arrays.asList(split));
        boolean b = goodsService.removeByIds(list);
        return b?success():fail();
    }



}
