package com.eleadmin.common.goods.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.util.Date;

/**
 * 商品
 *
 * @program: ele-admin-api
 * @ClassName: Goods
 * @author: Gyc
 * @create: 2024-04-21 09:25
 **/
@Data
@AllArgsConstructor
@NoArgsConstructor
@ApiModel(description = "商品")
@TableName("goods")
public class Goods implements Serializable {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty("主键id")
    @TableId(type = IdType.AUTO)
    private Integer id;

    @ApiModelProperty("商品编码")
    private String goodId;

    @ApiModelProperty("商品名称")
    @NotEmpty(message = "商品名称不能为空")
    private String title;

    @ApiModelProperty("商品类型,1上架,2下架")
    @NotNull(message = "商品类型不能为空")
    @Min(value = 1)
    @Max(value = 2)
    private Integer goodType;

    @ApiModelProperty("商品价格")
    @NotNull(message = "商品价格不能为空")
    @Min(value = 1)
    private Integer price;

    @ApiModelProperty("创建时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    @ApiModelProperty("创建人")
    private Integer creaorId;


    @ApiModelProperty("修改时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date changeDate;

    @ApiModelProperty("修改人")
    private Integer changorId;

}
